@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use Carp qw( croak );
 use DateTime 1.45;
@@ -698,7 +698,15 @@ DateTime::Format::Builder->create_class(
                     \&_fractional_second,
                 ],
             },
-
+            {
+                #YYYYMMDDThhmm[+-]hhmm 19850412T1015+0400
+                #YYYY-MM-DDThh:mm[+-]hh:mm 1985-04-12T10:15+04:00
+                length => [qw( 18 22 )],
+                regex  => qr/^ (\d{4}) -??  (\d\d) -?? (\d\d)
+                             T (\d\d) :?? (\d\d) ([+-] \d\d :?? \d\d) $/x,
+                params      => [qw( year month day hour minute time_zone )],
+                postprocess => \&_normalize_offset,
+            },
             {
                 #YYYYMMDDThhmmss[+-]hhmm 19850412T101530+0400
                 #YYYY-MM-DDThh:mm:ss[+-]hh:mm 1985-04-12T10:15:30+04:00
@@ -1095,14 +1103,14 @@ DateTime::Format::ISO8601 - Parses ISO8601 formats
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
     use DateTime::Format::ISO8601;
 
     my $datetime_str = '2020-07-25T11:32:31';
-    my $dt       = DateTime::Format::ISO8601->parse_datetime($datetime_str);
+    my $dt = DateTime::Format::ISO8601->parse_datetime($datetime_str);
     say $dt;
 
     # This format is ambiguous and could be either a date or time, so use the
@@ -1124,8 +1132,8 @@ version 0.15
 
 =head1 DESCRIPTION
 
-Parses almost all ISO8601 date and time formats. ISO8601 time-intervals will
-be supported in a later release.
+Parses almost all ISO8601 date and time formats. ISO8601 time-intervals will be
+supported in a later release.
 
 =head1 METHODS
 
@@ -1154,8 +1162,8 @@ This key is optional.
 
 =item * cut_off_year
 
-A integer representing the cut-off point between interpreting 2-digits years
-as 19xx or 20xx.
+A integer representing the cut-off point between interpreting 2-digits years as
+19xx or 20xx.
 
     2-digit years <  cut_off_year will be interpreted as 20xx
     2-digit years >= cut_off_year will be untreated as 19xx
@@ -1165,8 +1173,8 @@ This key defaults to the value of C<DefaultCutOffYear>.
 =item * legacy_year
 
 A boolean value controlling if a 2-digit year is interpreted as being in the
-current century (unless a C<base_datetime> is set) or if C<cut_off_year>
-should be used to place the year in either 20xx or 19xx.
+current century (unless a C<base_datetime> is set) or if C<cut_off_year> should
+be used to place the year in either 20xx or 19xx.
 
 If this is true, then the C<cut_off_year> is used. If this is false, then the
 year is always interpreted as being in the current century.
@@ -1192,13 +1200,13 @@ from incomplete date/time formats.
 
 =head3 $iso8601->cut_off_year
 
-Returns a integer representing the cut-off point between interpreting
-2-digits years as 19xx or 20xx.
+Returns a integer representing the cut-off point between interpreting 2-digits
+years as 19xx or 20xx.
 
 =head3 $iso8601->set_cut_off_year($int)
 
-Accepts a integer representing the cut-off point between interpreting
-2-digits years as 19xx or 20xx.
+Accepts a integer representing the cut-off point between interpreting 2-digits
+years as 19xx or 20xx.
 
     2-digit years <  legacy_year will be interpreted as 20xx
     2-digit years >= legacy_year will be interpreted as 19xx
@@ -1210,17 +1218,17 @@ Returns a boolean value indicating the 2-digit year handling behavior.
 =head3 $iso8601->set_legacy_year($bool)
 
 Accepts a boolean value controlling if a 2-digit year is interpreted as being
-in the current century (unless a C<base_datetime> is set) or if
-C<cut_off_year> should be used to place the year in either 20xx or 19xx.
+in the current century (unless a C<base_datetime> is set) or if C<cut_off_year>
+should be used to place the year in either 20xx or 19xx.
 
 =head2 Class Methods
 
 =head3 DateTime::Format::ISO8601->DefaultCutOffYear($int)
 
-Accepts a integer representing the cut-off point for 2-digit years when
-calling C<parse_*> as class methods and the default value for C<cut_off_year>
-when creating objects. If called with no parameters this method will return
-the default value for C<cut_off_year>.
+Accepts a integer representing the cut-off point for 2-digit years when calling
+C<parse_*> as class methods and the default value for C<cut_off_year> when
+creating objects. If called with no parameters this method will return the
+default value for C<cut_off_year>.
 
 =head3 DateTime::Format::ISO8601->DefaultLegacyYear($bool)
 
@@ -1251,10 +1259,10 @@ timezone offset.
 
 =head1 FORMATS
 
-There are 6 strings that can match against date only or time only formats.
-The C<parse_datetime> method will attempt to match these ambiguous strings
-against date only formats. If you want to match against the time only formats
-use the C<parse_time> method.
+There are 6 strings that can match against date only or time only formats. The
+C<parse_datetime> method will attempt to match these ambiguous strings against
+date only formats. If you want to match against the time only formats use the
+C<parse_time> method.
 
 =head2 Conventions
 
@@ -1262,14 +1270,14 @@ use the C<parse_time> method.
 
 =item * Expanded ISO8601
 
-These formats are supported with exactly 6 digits for the year.
-Support for a variable number of digits will be in a later release.
+These formats are supported with exactly 6 digits for the year. Support for a
+variable number of digits will be in a later release.
 
 =item * Precision
 
-If a format doesn't include a year all larger time unit up to and including
-the year are filled in using the current date/time or [if set] the
-C<base_datetime> object.
+If a format doesn't include a year all larger time unit up to and including the
+year are filled in using the current date/time or [if set] the C<base_datetime>
+object.
 
 =item * Fractional time
 
@@ -1279,8 +1287,8 @@ There is no limit on the expressed precision.
 
 =head2 Supported via parse_datetime
 
-The supported formats are listed by the section of ISO 8601:2000(E) in
-which they appear.
+The supported formats are listed by the section of ISO 8601:2000(E) in which
+they appear.
 
 =head3 5.2 Dates
 
@@ -1677,14 +1685,13 @@ Values can optionally be prefixed with 'T'.
 
 =head1 CREDITS
 
-Iain 'Spoon' Truskett (SPOON) who wrote L<DateTime::Format::Builder>.
-That has grown into I<The Vacuum Energy Powered C<Swiss Army> Katana>
-of date and time parsing. This module was inspired by and conceived
-in honor of Iain's work.
+Iain 'Spoon' Truskett (SPOON) who wrote L<DateTime::Format::Builder>. That has
+grown into I<The Vacuum Energy Powered C<Swiss Army> Katana> of date and time
+parsing. This module was inspired by and conceived in honor of Iain's work.
 
 Tom Phoenix (PHOENIX) and PDX.pm for helping me solve the ISO week conversion
-bug. Not by fixing the code but motivation me to fix it so I could
-participate in a game of C<Zendo>.
+bug. Not by fixing the code but motivation me to fix it so I could participate
+in a game of C<Zendo>.
 
 Jonathan Leffler (JOHNL) for reporting a test bug.
 
@@ -1734,7 +1741,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Doug Bell joe Thomas Klausner
+=for stopwords Doug Bell joe Liam Widdowson Thomas Klausner
 
 =over 4
 
@@ -1748,13 +1755,17 @@ joe <draxil@gmail.com>
 
 =item *
 
+Liam Widdowson <lbw@telstra.com>
+
+=item *
+
 Thomas Klausner <domm@plix.at>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Joshua Hoblitt.
+This software is copyright (c) 2021 by Joshua Hoblitt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
